pub enum AudioCacheMode {
Ignore,
Cache,
Retry,
Reload,
}Expand description
Cache mode of AUDIOS.
Variants
Ignore
Don’t hit the cache, just loads the audio.
Cache
Gets a cached audio or loads the audio and caches it.
Retry
Cache or reload if the cached audio is an error.
Reload
Reloads the cache audio or loads the audio and caches it.
The AudioVar is not replaced, other references to the audio also receive the update.