#[non_exhaustive]pub enum AudioOutputState {
Playing,
Paused,
Stopped,
}Expand description
Represents the playback state if an audio output stream.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Playing
Audio is sent to the device for playback as in the sequence they are cued.
Paused
Audio playback is paused, cue requests are buffered.
Stopped
Audio playback is paused, all current cue requests are dropped.
Implementations