#[non_exhaustive]pub struct AudioLimits {
pub max_encoded_len: ByteLength,
pub max_decoded_len: ByteLength,
pub allow_path: PathFilter,
pub allow_uri: UriFilter,
}Expand description
Limits for audio loading and decoding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_encoded_len: ByteLengthMaximum encoded file size allowed.
An error is returned if the file size surpasses this value. If the size can read before read/download the validation happens before download starts, otherwise the error happens when this limit is reached and all already downloaded bytes are dropped.
The default is 100mb.
max_decoded_len: ByteLengthMaximum decoded file size allowed.
An error is returned if the decoded audio memory (width * height * 4) would surpass this.
allow_path: PathFilterFilter for AudioSource::Read paths.
allow_uri: UriFilterFilter for AudioSource::Download URIs.
Implementations
Sourceimpl AudioLimits
impl AudioLimits
Sourcepub fn with_max_encoded_len(
self,
max_encoded_len: impl Into<ByteLength>,
) -> Self
pub fn with_max_encoded_len( self, max_encoded_len: impl Into<ByteLength>, ) -> Self
Set the max_encoded_len.
Sourcepub fn with_max_decoded_len(
self,
max_decoded_len: impl Into<ByteLength>,
) -> Self
pub fn with_max_decoded_len( self, max_decoded_len: impl Into<ByteLength>, ) -> Self
Set the max_decoded_len.
Sourcepub fn with_allow_path(self, allow_path: impl Into<PathFilter>) -> Self
pub fn with_allow_path(self, allow_path: impl Into<PathFilter>) -> Self
Set the allow_path.
Sourcepub fn with_allow_uri(self, allow_url: impl Into<UriFilter>) -> Self
pub fn with_allow_uri(self, allow_url: impl Into<UriFilter>) -> Self
Set the allow_uri.