AudioOutput

Struct AudioOutput 

pub struct AudioOutput(/* private fields */);
Represents an open audio output stream.

You can use AUDIOS.open_output to open a new output stream.

Implementations

Source

impl AudioOutput

pub fn id(&self) -> AudioOutputId

Unique ID of this output.

pub fn cue(&self, audio: impl Into<AudioMix>)

Enqueue the audio for playback in this output.

The audio will play when the output is playing and the previous cued audio finishes.

pub fn volume(&self) -> Var<Factor>

Volume of the sound.

The value multiplies the samples, 1.fct() is the natural volume from the source.

pub fn speed(&self) -> Var<Factor>

Speed of the sound.

This is a multiplier of the playback speed and pitch.

  • 0.5.fct() doubles the total duration and halves (lowers) the pitch.
  • 2.fct() halves the total duration and doubles (raises) the pitch.
pub fn state(&self) -> Var<AudioOutputState>

Output playback state.

This variable can be set to change the state.

Note that because variable modifications apply at once you cannot stop and play in the same update cycle using this. Use the

The default value is AudioOutputState::Playing.

pub fn play(&self)

Change state to Playing.

Audio is sent to the device for playback as audio is cued.

pub fn pause(&self)

Change state to Paused.

Audio playback is paused, cue requests are buffered.

pub fn stop(&self)

Change state to Stopped.

Audio playback is paused, all current cue requests are dropped.

pub fn stop_play(&self)

Change state to Stopped and then Playing in the same update cycle.

pub fn perm(&self)

Keep the audio output open until the end of the app.

pub fn is_connected(&self) -> Var<bool>

Read-only variable that tracks if this output is connected with the view-process.

When this is false the error might be set. Outputs automatically try to reconnect in case of view-process respawn, but note that it will respawn in the Stopped state.

pub fn error(&self) -> Var<Option<Txt>>

Gets an error message if view-process connection has failed.

Reconnection is attempted on view-process respawn, the is_connected tracks the ok status. Note that the first connection attempt is true in is_connected and None here.

Source

impl AudioOutput

pub fn downgrade(&self) -> WeakAudioOutput

Create a weak reference to this audio output.