pub struct AudioTracksMode(/* private fields */);Expand description
Defines what tracks are decoded from multi track containers.
Implementations
Sourceimpl AudioTracksMode
impl AudioTracksMode
Sourcepub const TRACKS: AudioTracksMode
pub const TRACKS: AudioTracksMode
Decodes all tracks.
Sourcepub const PRIMARY: AudioTracksMode
pub const PRIMARY: AudioTracksMode
Decodes only the first track, or the track explicitly marked as primary/default by the container format.
Note that this is 0, empty.
Sourceimpl AudioTracksMode
impl AudioTracksMode
Sourcepub const fn empty() -> AudioTracksMode
pub const fn empty() -> AudioTracksMode
Get a flags value with all bits unset.
Sourcepub const fn all() -> AudioTracksMode
pub const fn all() -> AudioTracksMode
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<AudioTracksMode>
pub const fn from_bits(bits: u8) -> Option<AudioTracksMode>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> AudioTracksMode
pub const fn from_bits_truncate(bits: u8) -> AudioTracksMode
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> AudioTracksMode
pub const fn from_bits_retain(bits: u8) -> AudioTracksMode
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AudioTracksMode>
pub fn from_name(name: &str) -> Option<AudioTracksMode>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AudioTracksMode) -> bool
pub const fn intersects(&self, other: AudioTracksMode) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AudioTracksMode) -> bool
pub const fn contains(&self, other: AudioTracksMode) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AudioTracksMode)
pub fn insert(&mut self, other: AudioTracksMode)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AudioTracksMode)
pub fn remove(&mut self, other: AudioTracksMode)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AudioTracksMode)
pub fn toggle(&mut self, other: AudioTracksMode)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AudioTracksMode, value: bool)
pub fn set(&mut self, other: AudioTracksMode, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AudioTracksMode) -> AudioTracksMode
pub const fn intersection(self, other: AudioTracksMode) -> AudioTracksMode
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AudioTracksMode) -> AudioTracksMode
pub const fn union(self, other: AudioTracksMode) -> AudioTracksMode
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: AudioTracksMode) -> AudioTracksMode
pub const fn difference(self, other: AudioTracksMode) -> AudioTracksMode
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AudioTracksMode,
) -> AudioTracksMode
pub const fn symmetric_difference( self, other: AudioTracksMode, ) -> AudioTracksMode
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AudioTracksMode
pub const fn complement(self) -> AudioTracksMode
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AudioTracksMode
impl AudioTracksMode
Sourcepub const fn iter(&self) -> Iter<AudioTracksMode>
pub const fn iter(&self) -> Iter<AudioTracksMode>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AudioTracksMode>
pub const fn iter_names(&self) -> IterNames<AudioTracksMode>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.