pub struct AudioOutput(/* private fields */);Expand description
Represents an open audio output stream.
You can use AUDIOS.open_output to open a new output stream.
Implementations
Sourceimpl AudioOutput
impl AudioOutput
Sourcepub fn id(&self) -> AudioOutputId
pub fn id(&self) -> AudioOutputId
Unique ID of this output.
Sourcepub fn cue(&self, audio: impl Into<AudioMix>)
pub fn cue(&self, audio: impl Into<AudioMix>)
Enqueue the audio for playback in this output.
The audio will play when the output is playing and the previous cued audio finishes.
Sourcepub fn volume(&self) -> Var<Factor>
pub fn volume(&self) -> Var<Factor>
Volume of the sound.
The value multiplies the samples, 1.fct() is the natural volume from the source.
Sourcepub fn speed(&self) -> Var<Factor>
pub fn speed(&self) -> Var<Factor>
Speed of the sound.
This is a multiplier of the playback speed and pitch.
0.5.fct()doubles the total duration and halves (lowers) the pitch.2.fct()halves the total duration and doubles (raises) the pitch.
Sourcepub fn state(&self) -> Var<AudioOutputState>
pub fn state(&self) -> Var<AudioOutputState>
Output playback state.
This variable can be set to change the state.
Note that because variable modifications apply at once you cannot stop and play in the same update cycle using this. Use the
The default value is AudioOutputState::Playing.
Sourcepub fn pause(&self)
pub fn pause(&self)
Change state to Paused.
Audio playback is paused, cue requests are buffered.
Sourcepub fn stop(&self)
pub fn stop(&self)
Change state to Stopped.
Audio playback is paused, all current cue requests are dropped.
Sourcepub fn is_connected(&self) -> Var<bool>
pub fn is_connected(&self) -> Var<bool>
Sourcepub fn error(&self) -> Var<Option<Txt>>
pub fn error(&self) -> Var<Option<Txt>>
Gets an error message if view-process connection has failed.
Reconnection is attempted on view-process respawn, the is_connected tracks the ok status. Note that
the first connection attempt is true in is_connected and None here.
Sourceimpl AudioOutput
impl AudioOutput
Sourcepub fn downgrade(&self) -> WeakAudioOutput
pub fn downgrade(&self) -> WeakAudioOutput
Create a weak reference to this audio output.